const std  = @import("std");
const dvui = @import("dvui");

const ui = @import("../ui/root.zig");

pub fn gui(src: std.builtin.SourceLocation, ctx: anytype) !void {
    const id       = ctx.id();
    const summary  = ctx.summary();
    const done     = ctx.done();
    const archived = ctx.archived();
    const staged   = ctx.staged();

    var card = try dvui.box(src, .horizontal, .{
        .id_extra   = id,
        .expand     = .horizontal,
        .background = true,
        .border     = dvui.Rect.all(1),
    });
    defer card.deinit();

    {
        var check = done;
        const changed = try dvui.checkbox(@src(), &check, null, .{
            .gravity_y = 0.5,
            .gravity_x = 0,
        });
        if (changed) {
            std.debug.print("CHANGED\n", .{});
        }
    }

    const hover = true;
    if (hover) {
        var icons = try dvui.box(@src(), .horizontal, .{
            .expand    = .vertical,
            .gravity_x = 1,
        });
        defer icons.deinit();

        if (staged) {
            if (try buttonIcon(@src(), "unstage", dvui.entypo.light_down)) {
                std.debug.print("UNSTAGE\n", .{});
            }
        } else {
            if (try buttonIcon(@src(), "stage", dvui.entypo.light_up)) {
                std.debug.print("STAGE\n", .{});
            }
        }
        if (archived) {
            if (try buttonIcon(@src(), "unarchive", dvui.entypo.back_in_time)) {
                std.debug.print("UNARCHIVE\n", .{});
            }
        } else {
            if (try buttonIcon(@src(), "archive", dvui.entypo.archive)) {
                std.debug.print("ARCHIVE\n", .{});
            }
        }
    }

    const open = try dvui.labelClick(@src(), "#{d} {s}", .{ ctx.id(), summary, }, .{
        .expand    = .horizontal,
        .gravity_x = 0,
    });
    if (open) {
        std.debug.print("OPEN\n", .{});
    }
}

fn buttonIcon(src: std.builtin.SourceLocation, name: []const u8, icon: []const u8) !bool {
    return try dvui.buttonIcon(src, name, icon, .{}, .{
        .margin    = dvui.Rect.all(0),
        .padding   = dvui.Rect.all(4),
        .gravity_y = 0.5,
    });
}
